@@ -26,9 +26,11 @@ use Pod::Usage;
 use File::Basename;
 use Curses;
 use Curses::UI;
+use List::Util qw ( first any );
 use List::UtilsBy qw ( max_by min_by uniq_by );
 use App::SysVRcConf::LSB;
 use IPC::Open3;
+use Storable qw(dclone);
 
 use constant {
     BOTTOM_LAB_HEIGHT   => 2,
@@ -43,10 +45,65 @@ use constant {
     TOP_LABEL_HEIGHT    => 2,
 };
 
+# Runlevel patterns: [ state regex, inverse video, colour, summary ]
+my $rl_patterns = [
+    [qr(^01111002),           0, "green",   "Multiuser"],
+    [qr(^12222222),           0, "yellow",  "Single user"],
+    [qr(^02222222),           0, "red",     "Off (single user)"],
+    [qr(^10000002),           0, "yellow",  "Single user"],
+    [qr(^12222222),           0, "yellow",  "Single user oneshot"],
+    [qr(^11111222),           0, "yellow",  "Single and multiuser linger"],
+    [qr(^11111002),           0, "yellow",  "Single and multiuser"],
+    [qr(^22222221),           0, "cyan",    "Startup"],
+    [qr(^22222220),           0, "red",     "Off (startup/shutdown)"],
+    [qr(^21111002),           0, "cyan",    "Multiuser startup"],
+    [qr(^22222222),           1, "red",     "No symlinks"],
+    [qr(^[02]1111222),        0, "green",   "Multiuser linger"],
+    [qr(^[02]0000[02][02]2),  0, "red",     "Off"],
+    [qr(^[02][01]*1[01]*[02][02]2$),
+                              1, "green",   "Custom multiuser"],
+    [qr(^[02]2222001),        0, "cyan",    "Startup and shutdown"],
+    [qr(^22222[02]*0[02]*2$), 0, "magenta", "Shutdown"],
+    [qr(0$),                  1, "red",     "Likely error"],
+    [qr(^......*1.*.$),       1, "red",     "Likely error"],
+    [qr(.*),                  0, "",        "Custom"]
+];
+
 my $OURNAME = "sysv-rc-conf";
-my $VERSION = "1.1.1";
+my $VERSION = "1.2.0";
 my $called_as_chkconfig = $0 =~ /chkconfig$/;
 
+my %def_alt_init_handler = (
+    is_managed => sub { return 0; },
+);
+
+my %runit_handler = (
+    manager => "runit",
+    is_managed => sub {
+        my ($sn) = shift;
+        return ( -f "/etc/runit/override-sysv.d/$sn.block" ||
+                 -f "/etc/runit/override-sysv.d/$sn.pkgblock" ||
+                  ( ! -f "/etc/runit/override-sysv.d/$sn.sysv" &&
+                    ( -l "/etc/service/$sn" ||
+                      -d "/etc/sv/$sn" ||
+                      -d "/usr/share/runit/sv.current/$sn" )));
+    },
+);
+
+my %systemd_handler = (
+    manager => "systemd",
+    is_managed => sub {
+        my ($sn) = shift;
+        # Do not include generator paths
+        my @dirs = ( "/etc/systemd/system",
+                     "/run/systemd/system",
+                     "/usr/local/lib/systemd/system",
+                     "/usr/lib/systemd/system",
+                   );
+        return any { -e "$_/$sn.service" || -e "$_/$sn.target" } @dirs;
+    },
+);
+
 my %opts = (
     cache_dir   => undef,
     order       => 'a',
@@ -67,14 +124,21 @@ my %opts = (
     read_only   => 0,
     ui          => undef,
     insserv     => 0,
+    interpret   => 1,
+    defdiff     => 1,
+    pictograms  => ($ENV{LANG} =~ /\.UTF-8$/ ? 1 : 0),
 );
 my @mutually_exclusive_options = qw(chkcfg_list chkcfg_add chkcfg_del);
 
 if (open (my $conf, "<", "/etc/sysv-rc-conf.conf")) {
     while (<$conf>) {
 	next if /^\s*#/ or /^\s*$/;
-	/^\s*(\S+)(?:\s+([^#]*?))?\s*(?:#.*)?$/ or die "malformed config line: $_";
-	$opts{$1} = $2 ne '' ? $2 : 1;
+	my ($k, $v) = /^\s*(\S+)(?:\s+([^#]*?))?\s*(?:#.*)?$/ or die "malformed config line: $_";
+        if ($k =~ /^no-(.*)$/) {
+            $k = $1;
+            $v = 0;
+        }
+	$opts{$k} = $v ne '' ? $v : 1;
     }
     close $conf;
 }
@@ -99,6 +163,12 @@ GetOptions("cache=s"	=> \$opts{cache_dir},
            "UI"         => \$opts{ui},
            "batch"      => sub { $opts{ui} = 0; },
            "insserv"    => \$opts{insserv},
+           "interpret"      =>      \$opts{interpret},
+           "no-interpret"   => sub { $opts{interpret} = 0; },
+           "pictograms"     =>      \$opts{pictograms},
+           "no-pictograms"  => sub { $opts{pictograms} = 0; },
+           "defdiff"        =>      \$opts{defdiff},
+           "no-defdiff"     => sub { $opts{defdiff} = 0; },
 	  ) or exit(1);
 
 $opts{cache_dir} //= "$opts{root}var/lib/sysv-rc-conf";
@@ -123,9 +193,11 @@ my @valid_rls = grep { -d "$etc_rc$_.d" } @rls;
 my $retcode = undef;
 my $first_write_attempted = 0;
 my $passive_ops_only = 0;
+my $delta = $opts{pictograms} ? "\x{0394}" : '#';
 
 my $LSB = App::SysVRcConf::LSB->new(root => $opts{root}, initd => "$initd/", ignore_errors => 1);
 my $runlevel_cmd = '/sbin/runlevel';
+my $alt_init_handler = \%def_alt_init_handler;
 my $unsuitable_init = check_suitable_init();
 check_root_access();
 check_args();
@@ -144,6 +216,7 @@ my @s = ();
 # All the runlevel information
 my @status_data = runlevel_status();
 my %runlevels = %{$status_data[0]};
+my %runlevels_ui = %{dclone($status_data[0])};
 my %services = %{$status_data[1]};
 my $longest_service = length (max_by { length($_) } (keys %runlevels));
 
@@ -173,6 +246,7 @@ my $cui;
 my @snames_per_screen;
 my %box_pos;
 my %service_controls = ();
+my %extra_controls = ();
 
 if ($opts{ui}) {
     $cui = new Curses::UI( -clear_on_exit    => 0,
@@ -186,7 +260,7 @@ if ($opts{ui}) {
     create_bottom_box();
     create_main_window( \%service_controls );
     $cui->set_binding( \&toggle_help,    "h" );
-    $cui->set_binding( \&revert_changes, "r") ;
+    $cui->set_binding( \&revert_changes, "r" );
     $s[$current_screen]->focus();
 }
 
@@ -227,6 +301,7 @@ sub update_link
     if (defined $sn && defined $rl && defined $sk && defined $pri) {
         if (-e "$etc_rc$rl.d/$sk$pri$sn") {
             # The symlink we are trying to make already exists
+            $runlevels_ui{$sn}{$rl} = "$sk$pri";
             return 'exists';
         }
     }
@@ -240,9 +315,12 @@ sub update_link
 	    or die "Can't unlink $etc_rc$rl.d/$_ : $!";
     }
 
-    # If in priority mode and are completely deleting the link, $sk will
+    # If completely deleting the link, $sk will
     # be empty.
-    return 1 if !(defined $sk) || $sk eq '';
+    if (!(defined $sk) || $sk eq '') {
+        $runlevels_ui{$sn}{$rl} = undef;
+        return 1;
+    }
 
     $pri = get_pri_cache($sn, $rl, $sk) unless $pri;
 
@@ -251,6 +329,7 @@ sub update_link
 
     verbose("symlink $initd/$sn $etc_rc$rl.d/$sk$pri$sn");
     # unlike ln relative symlinks are relative to the target file, not the cwd
+    $runlevels_ui{$sn}{$rl} = "$sk$pri";
     return unless write_ok();
     symlink "../init.d/$sn", "$etc_rc$rl.d/$sk$pri$sn"
         or die "Can't symlink $etc_rc$rl.d/$sk$pri$sn to ../init.d/$sn : $!\n";
@@ -392,46 +471,61 @@ sub list_output
     }
 }
             
-sub revert_changes
+sub revert_service
 {
-    # Lookup table
+    my $sn = shift;
     my %cache = %{service_controls};
 
-    foreach my $sn (keys %runlevels) {
-        foreach my $rl (keys %{$runlevels{$sn}}) {
-            $runlevels{$sn}{$rl} =~ /^([SK])(\d\d)$/;
-            my ($sk, $pri) = ($1, $2);
+    foreach my $rl (keys %{$runlevels{$sn}}) {
+        $runlevels{$sn}{$rl} =~ /^([SK])(\d\d)$/;
+        my ($sk, $pri) = ($1, $2);
 
-	    # In RW mode, trying to revert the link will tell us if UI needs reverting
-            next if write_ok() and update_link($sn, $rl, $sk, $pri) eq 'exists';
+        # In RW mode, trying to revert the link will tell us if UI needs reverting
+        next if update_link($sn, $rl, $sk, $pri) eq 'exists' and write_ok();
 
-            if (defined($cache{$sn}{$rl})) {
-                my $box = $cache{$sn}{$rl};
-                if ($opts{priority}) { 
-                    # Reset the text
-                    $box->text($sk.$pri);
-                    $box->draw(1);
-                }
-                else {
-                    # Simple layout, just toggle the box.
-                    $box->set($sk eq 'K' ? 0 : 1);
-                    $box->draw(1);
-                }
+        if (defined($cache{$sn}{$rl})) {
+            my $box = $cache{$sn}{$rl};
+            if ($opts{priority}) {
+                # Reset the text
+                $box->text($sk.$pri);
+                $box->draw(1);
+            }
+            else {
+                # Simple layout, just toggle the box.
+                $box->set($sk eq 'K' ? 0 : 1);
+                $box->draw(1);
             }
-	}
-	unless ($opts{priority}) {
-	    foreach my $rl (keys %{$cache{$sn}}) {
-		if (!defined($runlevels{$sn}{$rl})) {
-		    my $box = $cache{$sn}{$rl};
-                    update_link($sn, $rl, '', undef) if write_ok();
-		    $box->set(2);
-		    $box->draw(1);
-		}
-	    }
         }
     }
+    unless ($opts{priority}) {
+        foreach my $rl (keys %{$cache{$sn}}) {
+            if (!defined($runlevels{$sn}{$rl})) {
+                my $box = $cache{$sn}{$rl};
+                    update_link($sn, $rl, '', undef);
+                $box->set(2);
+                $box->draw(1);
+            }
+        }
+    }
+    update_note($sn);
+}
 
-    $cui->dialog("Symlinks restored to original state!");
+sub revert_changes
+{
+    foreach my $sn (keys %runlevels) {
+        revert_service($sn);
+    }
+
+    $cui->dialog("All symlinks restored to original state!");
+}
+
+sub revert_one
+{
+    my ($widget) = @_;
+    my $ud = $widget->userdata();
+
+    revert_service($ud->{sn});
+    $widget->focus();
 }
 
 sub start_service
@@ -461,6 +555,30 @@ sub st_service
     $cui->dialog("Results of /usr/sbin/service $sn $st (return code $rc):\n" . $output);
 }
 
+sub update_note
+{
+    my ($sn) = shift;
+
+    my $infobox = $extra_controls{$sn}{"info"};
+    my $defdiff = $extra_controls{$sn}{"defdiff"};
+    return if !defined $infobox and !defined $defdiff;
+
+    my $rl_state = rl_str($sn);
+
+    if (defined $infobox) {
+        my ($invert, $colour, $note) = interp($sn, $rl_state);
+        $infobox->text($note);
+        $infobox->set_color_fg($colour);
+        $infobox->reverse($invert);
+        $infobox->draw(1);
+    }
+
+    if (defined $defdiff) {
+        my $lsb_rls = $services{$sn}->{lsb_rls};
+        $defdiff->text(default_status($lsb_rls, $rl_state));
+    }
+}
+
 sub toggle_multiuser
 {
     my ($widget) = @_;
@@ -468,23 +586,28 @@ sub toggle_multiuser
     my $sn = $ud->{sn};
     my $multiuser = qr/[2345]/;
     my @multirls = grep { $_ =~ $multiuser } @rls;
+    my @multishowrls = grep { $_ =~ $multiuser } @show_rls;
     my %controls = %{$service_controls{$sn}};
     my $w = $widget;
     my $next;
 
     # Decide current state based on where cursor is if possible
     if ($ud->{runlevel} !~ $multiuser) {
-	# else if any of the multiuser services is ON, switch all to OFF
-        $w = $controls{max_by { $controls{$_}->get() == 1 } (@multirls)};
+        # else if any of the multiuser services is ON, switch all to OFF
+        $w = $controls{max_by { $controls{$_}->get() == 1 } (@multishowrls)};
     }
     $next = $w->get() == 1 ? 0 : 1;
 
     foreach my $rl (@multirls) {
-	my $box = $controls{$rl};
-        update_link($sn, $rl, $next ? 'S' : 'K', undef) if write_ok();
-	$box->set($next);
-	$box->draw(1);
+        my $box = $controls{$rl};
+
+        update_link($sn, $rl, $next ? 'S' : 'K', undef);
+        if (defined $box) {
+            $box->set($next);
+            $box->draw(1);
+        }
     }
+    update_note($sn);
     $widget->focus();
 }
 
@@ -505,13 +628,14 @@ sub set_lsb_defaults
 	       (map { $_ => 'K' } @{($lsb->{'Default-Stop'} // [])}));
 
     foreach my $rl (@valid_rls) {
-        update_link($sn, $rl, $def{$rl}, undef) if write_ok();
+        update_link($sn, $rl, $def{$rl}, undef);
     }
     foreach my $rl (@show_rls) {
 	my $box = $controls{$rl};
 	$box->set((defined $def{$rl}) ? ($def{$rl} eq 'S' ? 1 : 0) : 2);
 	$box->draw(1);
     }
+    update_note($sn);
     $widget->focus();
 }
 
@@ -601,20 +725,22 @@ sub simple_box_changed
     my ($box) = @_;
     my $userdata = $box->userdata();
     my $new_state = $box->get();
+    my $sn = $userdata->{sn};
 
     $userdata->{changed}++;
 
     if ($new_state == 1) {
-	update_link($userdata->{sn}, $userdata->{runlevel}, 'S', undef);
+	update_link($sn, $userdata->{runlevel}, 'S', undef);
     } 
     else {
         if ($new_state == 0) {
-            update_link($userdata->{sn}, $userdata->{runlevel}, 'K', undef);
+            update_link($sn, $userdata->{runlevel}, 'K', undef);
         }
         else {
-            update_link($userdata->{sn}, $userdata->{runlevel}, '', undef);
+            update_link($sn, $userdata->{runlevel}, '', undef);
         }
     }
+    update_note($userdata->{sn});
 }
 
 sub runlevel_status 
@@ -635,8 +761,14 @@ sub runlevel_status
 	# ignore stuff like README
 	$runlevels{$service} = { } if -x "$initd/$service";
 	my $lsb = $LSB->get_headers($service);
-	$info{'lsb_headers'} = $lsb;
-	$info{'lsb_info'} = $LSB->parse_headers($lsb) if defined $lsb;
+        if (defined $lsb) {
+            $info{lsb_headers} = $lsb;
+            $info{lsb_info} = $LSB->parse_headers($lsb);
+            my %defs = ((map { $_ => 1 } @{($info{lsb_info}->{'Default-Start'} // [])}),
+	                (map { $_ => 0 } @{($info{lsb_info}->{'Default-Stop'} // [])})) if defined $info{lsb_info};
+            $info{lsb_defaults} = \%defs;
+            $info{lsb_rls} = join "", (map { $info{lsb_defaults}->{$_} // 2 } qw( 1 2 3 4 5 0 6 S )) if defined $info{lsb_defaults};
+        }
 	$services{$service} = \%info;
     }
     closedir INITD or die "$0: closedir $initd : $!";
@@ -785,9 +917,16 @@ sub check_suitable_init
     if ($opts{root} ne '/') {
         return undef;
     } elsif ( -d "/run/systemd/system" ) {
+        $alt_init_handler = \%systemd_handler;
         return "systemd is init;\n" .
                "${OURNAME}'s controls will be ineffective.\n" .
                "Use systemctl(1).";
+    } elsif ( -f "/run/runit.stopit" ) {
+        $alt_init_handler = \%runit_handler;
+        return "runit is init;\n" .
+               "${OURNAME}'s controls will be ineffective for services with " .
+               "service directories managed by runit.\n" .
+	       "Use update-service(8).";
     } else {
         return undef;
     }
@@ -818,7 +957,6 @@ sub current_runlevel
     }
 }
 
-
 sub probably_oneshot
 {
     my $service = shift;
@@ -859,7 +997,11 @@ sub split_services
             foreach my $sn (sort keys %runlevels) {
                 next unless exists $runlevels{$sn}{$o_opts{rl}};
                 next unless $runlevels{$sn}{$o_opts{rl}} =~ /^[SK](\d\d)$/;
-                push @services, $1.$sn;
+                my $render_as = "$1 $sn";
+                push @services, $render_as;
+                if (length $render_as > $longest_service) {
+		    $longest_service = length $render_as;
+		}
             }
         }
         elsif (exists $o_opts{s}) {
@@ -905,7 +1047,7 @@ sub split_services
         # the default of just 'a' being set.
         my %seen = ();
         foreach (@services) {
-            next unless $_ =~ /^(\d\d)?(.+)$/;
+            next unless $_ =~ /^(\d\d )?(.+)$/;
             $seen{$2} = 1;
         }
 
@@ -968,6 +1110,7 @@ sub verbose { print VERBOSE $_[0]."\n" if $opts{verbose}; }
 sub create_main_window
 {
     my $service_controls = shift;
+    my $max_width;
 
     create_help_window();
     
@@ -985,11 +1128,12 @@ sub create_main_window
 	    -ipad	    => 1,
 	);
 
+        $max_width = $screen->width();
         $opts{label_width} //= max_by { $_ } (
             DEFAULT_LABEL_WIDTH,
             min_by { $_ } (
                 $longest_service,
-                $screen->width() - scalar(@show_rls) * 8 - 6
+                $max_width - scalar(@show_rls) * 8 - 6
             )
         );
 
@@ -1011,7 +1155,7 @@ sub create_main_window
 	my $left_label = '';
 	for (my $i = 0; $i < scalar(@$services); $i++) {
 	    $left_label .= $services->[$i] . "\n";
-	    if ($services->[$i] =~ /^\d\d(.+)$/) {
+	    if ($services->[$i] =~ /^\d\d (.+)$/) {
 		# If the labels had numbers, we don't need them anymore. 
 		$services->[$i] = $1;
 	    }
@@ -1032,7 +1176,7 @@ sub create_main_window
 	    if   ($opts{priority}) {
 		$controls = draw_priority_layout($screen, $sn, $row);
 	    } else {
-		$controls = draw_simple_layout($screen, $sn, $row);
+		$controls = draw_simple_layout($screen, $sn, $row, $max_width - 4);
 	    }
 	    $service_controls->{$sn} = $controls;
 	    $row++;
@@ -1053,6 +1197,7 @@ Quick key reference:
   PgDn or ^n: Next Page
   PgUp or ^p: Previous Page
   Home:       Go to first service
+  Backspace:  Restore service's symlinks back to state when started
   r:          Restore all symlinks back to state when sysv-rc-conf started
   -:          Stop service now
   +:          Start service now
@@ -1075,6 +1220,13 @@ Quick key reference:
     CTRL-f:     Move cursor forward through text
     CTRL-b:     Move cursor backwards through text
 
+Key to symbols:
+
+   $delta    The current runlevel symlinks differ from LSB defaults
+  [X]   A start ('S') symlink is present for the service at this runlevel
+  [ ]   A stop ('K') symlink is present for the service at this runlevel
+  [~]   No symlink is present for the service at this runlevel
+
   NOTE: When using either GUI layout (checkbox or priority), all
   configuration changes to the symlinks will happen IMMEDIATELY, not
   when the program exits.
@@ -1122,27 +1274,57 @@ EOF
 
 }
 
+sub rl_state
+{
+    my ($sn, $rl) = @_;
+
+    if (defined $runlevels_ui{$sn}{$rl}) {
+        if ($runlevels_ui{$sn}{$rl} =~ /^S\d\d$/) {
+            return 1;
+        }
+        return 0;
+    }
+    return 2;
+}
+
+sub rl_str {
+    my $sn = shift;
+    return join "", (map { rl_state($sn, $_) } qw( 1 2 3 4 5 0 6 S ));
+}
+
+sub interp
+{
+    my ($sn, $str) = @_;
+
+    if ($alt_init_handler->{is_managed}->($sn)) {
+        return (1, "blue", "$alt_init_handler->{manager}-managed");
+    }
+
+    return @{(first { $str =~ /$_->[0]/ } @{$rl_patterns})}[1..3];
+}
+
+sub default_status
+{
+    my ($lsb_rls, $rlstates) = @_;
+    return $lsb_rls eq $rlstates ? '' : $delta,
+}
+
 sub draw_simple_layout
 {
-    my ($screen, $sn, $row) = @_;
+    my ($screen, $sn, $row, $max_width) = @_;
     my %controls;
+    my $right_n = $opts{label_width} + 2;
 
-    for (my $i = 0, my $right_n = $opts{label_width} + 2; $i <= $#show_rls; $i++, $right_n += 8) {
+    for (my $i = 0; $i <= $#show_rls; $i++, $right_n += 8) {
 	my $rl = $show_rls[$i];
 	my $on_or_off = 0;
-        my $initial_state = 0;
+        my $state = rl_state($sn, $rl);
 	# We only want to show S\d\d services as selected. 
-        if (exists $runlevels{$sn}{$rl}) {
-            if ($runlevels{$sn}{$rl} =~ /^S\d\d$/) {
-                $on_or_off = 1;
-            }
-            $initial_state = 1;
-        }
 	my $id = cell_id($row - 2, $i);
         my $box = $screen->add(
             $id, 'App::SysVRcConf::Multistate',
             -label      => '',
-            -stateind   => $on_or_off ? 1 : ($initial_state ? 0 : 2),
+            -stateind   => $state,
             -border     => 0,
             -x          => $right_n,
             -y          => $row,
@@ -1152,13 +1334,13 @@ sub draw_simple_layout
 			     sn		=> $sn,
 			     changed	=> 0,
 			     runlevel	=> $rl,
-                             initial_state => $initial_state,
+                             initial_state => $state != 2 ? 1 : 0,
 			   },
             -onchange   => \&simple_box_changed,
             -onfocus    => \&got_focus,
 	    -states     => [ ' ', 'X', '~' ],
 	    -togglemap  => { 0 => $rl =~ /[06]/ ? 2 : 1,
-			     1 => $rl =~ /S/ ? 2 : ($initial_state ? 0 : 2),
+			     1 => $rl =~ /S/ ? 2 : ($state != 2 ? 0 : 2),
 			     2 => $rl =~ /[06]/ ? 0 : 1},
 	    -shortcuts  => { '0' => 0,
 			     'o' => 0,
@@ -1173,8 +1355,34 @@ sub draw_simple_layout
 	$box->set_binding( \&stop_service, "-" );
 	$box->set_binding( \&toggle_multiuser, "m" );
 	$box->set_binding( \&set_lsb_defaults, "d" );
+        $box->set_binding( \&revert_one,       KEY_BACKSPACE);
 	$controls{$rl} = $box;
     }
+    my $rlstates = rl_str($sn);
+    my $lsb_rls = $services{$sn}->{lsb_rls};
+    if ($opts{defdiff} and defined $lsb_rls) {
+        my $box = $screen->add(
+            "status:$sn", 'Label',
+            -text => default_status($lsb_rls, $rlstates),
+            -x    => $right_n + ($right_n == $max_width ? -2 : 0),
+            -y    => $row,
+            -width => 1,
+        );
+        $extra_controls{$sn}{"defdiff"} = $box;
+    }
+    if ($opts{interpret}) {
+        my ($inv, $col, $note) = interp($sn, $rlstates);
+        my $box = $screen->add(
+            "info:$sn", 'Label',
+            -text => $note,
+            -x    => $right_n + ($right_n == $max_width ? -1 : 2),
+            -y    => $row,
+            -reverse => $inv,
+            -fg   => $col,
+            -width => $right_n == $max_width ? 28 : 28,
+        );
+        $extra_controls{$sn}{"info"} = $box;
+    }
     return \%controls;
 }
 
@@ -1243,9 +1451,9 @@ sub create_top_label
 sub create_bottom_box
 {
     my $cmd_text = '';
-    my $extra_controls = "m: toggle multiuser runlevels   d: LSB defaults";
-    my $cursor = $ENV{LANG} =~ /\.UTF-8$/ ?
-	"\x{2190}\x{2191}\x{2193}\x{2192}\x{219f}\x{21a1}\x{2302}\x{1f5b1}" :
+    my $extra_controls = "m: toggle multiuser runlevels  d: defaults";
+    my $cursor = $opts{pictograms} ?
+	"\x{2190}\x{2191}\x{2193}\x{2192}\x{21de}\x{21df}\x{21f1}\x{1f5b1}" :
 	"<arrows>";
     if ($opts{priority}) {
 	$cmd_text = 
@@ -1269,8 +1477,9 @@ sub create_bottom_box
 	-y	=> 0,
 	-width	=> -1,
 	-height => BOTTOM_LAB_HEIGHT,
-	-text => 
-"$cursor   $extra_controls   r: restore all\n$cmd_text",
+	-text   => $opts{pictograms} ?
+"$cursor   $extra_controls  r/\x{232b}: restore all/one\n$cmd_text" :
+"$cursor  $extra_controls  r/BS: restore all/one\n$cmd_text",
     );
 }
 
@@ -1390,11 +1599,10 @@ B<sysv-rc-conf> [ --level I<levels> ] I<service> E<lt>I<on|off|reset>E<gt>
 
 =head1 DESCRIPTION
 
-B<sysv-rc-conf> gives an easy to use interface for managing
-C</etc/rc{runlevel}.d/> symlinks. The interface comes in two different
+B<sysv-rc-conf> gives an easy-to-use interface for managing
+C</etc/rc?.d/> symlinks. The interface comes in two different
 flavors, one that simply allows turning services on or off and another that
-allows for more fine tuned management of the symlinks. It's a replacement for
-programs like B<ntsysv(8)> or B<rcconf(8)>.
+allows for more fine-tuned management of the symlinks.
 
 B<sysv-rc-conf> can also be used at the command line when the desired changes
 to the symlinks are already known. The syntax is borrowed from B<chkconfig(8)>,
@@ -1510,6 +1718,10 @@ Alternate layout. Instead of just showing a checkbox, the priority of the
 service and the S or K are allowed to be edited. This is for more fine-tuned
 control then the default layout allows.
 
+On modern systems, it is more useful to enable the B<--insserv> option with the
+default layout, so that priority levels will be managed automatically based on
+dependencies encoded in LSB headers.
+
 =item B<-s> I<levels>, B<--show=>I<levels>
 
 Which runlevels to show. This defaults to up to 8 of the runlevels available
@@ -1518,6 +1730,22 @@ The syntax calls for the runlevels to be allruntogether. For instance, to
 show runlevels 3, 4, and 5 the syntax would be C<--show=345>. Also see 
 B<--order>.
 
+=item B<--interpret>, B<--no-interpret>
+
+Show (default), or do not show, an interpretation of the current runlevel
+symlinks on the right hand side of the simple view. This note is truncated
+if the terminal is wide enough.
+
+=item B<--defdiff>, B<--no-defdiff>
+
+Show (default), or do not show, a delta symbol on the right hand side when
+current runlevel settings differ from LSB defaults.
+
+=item B<--pictograms>, B<--no-pictograms>
+
+Show (default), or do not show, unicode pictogram characters in the user
+interface.
+
 =back
 
 =head2 CLI-Related Options
@@ -1585,6 +1813,10 @@ will be started when entering that runlevel. The two digits following is the
 order in which the services are started. That means that C<S08iptables> would
 start before C<S20ssh>. For more information see your system documentation.
 
+If the B<--insserv> option is in use then any tuning to the priority level will
+be lost on exit. It is unlikely that tuning the priority level manually will be
+useful on a modern system.
+
 =head2 Controls
 
 To move around use the arrow keys, or if the terminal support it, the mouse.
@@ -1594,16 +1826,17 @@ down or up at the bottom or top of the screen, respectively. The Home key
 will jump to the first service on the first page. The bottom of the
 screen also shows these movement commands for quick reference. To restore the
 symlinks back to their original state before the B<sysv-rc-conf> was run,
-press the B<r> key.  The B<h> key will display a quick reference help screen. 
+press the B<r> key. To restore just the current service's symlinks, press
+the B<backspace> key. The B<h> key will display a quick reference help screen.
 
 =head2 Default layout
 
-When using the default layout use the space bar to toggle the service with
-the most likely alternate setting in the context. The C<E<lt>> and C<E<gt>>
-keys cycle through the available states. The current runlevel can be set
-directly at the required state with C<0> or C<o> for stopping the service,
-C<1> or C<x> to start the service and C<2> or C<~> to leave the service
-floating.
+When using the default layout use the space bar to toggle the service with the
+most likely alternate setting in the context. The C<E<lt>> and C<E<gt>> keys
+cycle through the available states. The current runlevel can be set directly at
+the required state with C<0> or C<o> for stopping the service (a 'K' symlink),
+C<1> or C<x> to start the service (a 'S' symlink) and C<2> or C<~> to leave the
+service floating (no symlink).
 
 =head2 Priority layout
 
@@ -1709,9 +1942,9 @@ and the default priority of 80 for K links is used.
 
 =head1 COMPATIBILITY
 
-B<sysv-rc-conf> should work on any Unix like system that manages services 
-when changing runlevels by using symlinks in C</etc/rc{runlevel}.d/>. Refer
-to your system documentation to see if that's the case (usually there's a 
+B<sysv-rc-conf> should work on any Unix like system that manages services when
+changing runlevels by using symlinks in C</etc/rc?.d/>. Refer to your system
+documentation to see if that's the case (usually there's a
 C</etc/init.d/README>).
 
 =head1 CAVEATS
@@ -1721,8 +1954,8 @@ recommend to run B<insserv(8)> after adjusting service symlinks with
 B<sysv-rc-conf>. This can be done automatically using the B<--insserv> option,
 which may be included in the system config file.
 
-B<sysv-rc-conf> only manages the symlinks in the C<rc{runlevel}.d>
-directories. It's possible that packages may have other ways of being
+B<sysv-rc-conf> only manages the symlinks in the C<rc?.d>
+directories. It is possible that packages may have other ways of being
 disabled or enabled. 
 
 Because Curses takes over the screen sometimes error messages won't be
@@ -1734,13 +1967,13 @@ For example:
 
 =head1 REPORTING BUGS
 
-Report bugs at https://gitlab.com/abower/sysv-rc-conf/-/issues
+Report bugs at https://gitlab.com/init-tools/sysv-rc-conf/-/issues
 
 =head1 SEE ALSO
 
 B<insserv(8)>, B<init(8)>, B<runlevel(8)>, B<chkconfig(8)>, C</etc/init.d/README>
 
-  www: https://gitlab.com/abower/sysv-rc-conf
+  www: https://gitlab.com/init-tools/sysv-rc-conf
 
 =head1 AUTHOR
 
